Thread (128 messages) 128 messages, 3 authors, 2021-06-28

Re: [PATCH v2 34/46] mm/filemap: Add i_blocks_per_folio()

flat view

From: Christoph Hellwig <hch@infradead.org>
Date: 2021-06-23 09:47:24
Also in: linux-fsdevel, lkml

On Tue, Jun 22, 2021 at 01:15:39PM +0100, Matthew Wilcox (Oracle) wrote:
quoted hunk ↗ jump to hunk
Reimplement i_blocks_per_page() as a wrapper around i_blocks_per_folio().

Signed-off-by: Matthew Wilcox (Oracle) <willy@infradead.org>
---
 include/linux/pagemap.h | 18 ++++++++++++------
 1 file changed, 12 insertions(+), 6 deletions(-)
diff --git a/include/linux/pagemap.h b/include/linux/pagemap.h
index 31edfa891987..c30db827b65d 100644
--- a/include/linux/pagemap.h
+++ b/include/linux/pagemap.h
@@ -1149,19 +1149,25 @@ static inline int page_mkwrite_check_truncate(struct page *page,
 }
 
 /**
  * i_blocks_per_page - How many blocks fit in this page.
  * @inode: The inode which contains the blocks.
- * @page: The page (head page if the page is a THP).
+ * @folio: The folio.
  *
  * If the block size is larger than the size of this page, return zero.
  *
  * Context: The caller should hold a refcount on the page to prevent it
  * from being split.
  * Return: The number of filesystem blocks covered by this page.
  */
+static inline
+unsigned int i_blocks_per_folio(struct inode *inode, struct folio *folio)
@@ -1149,19 +1149,25 @@ static inline int page_mkwrite_check_truncate(struct page *page,
 
 /**
- * i_blocks_per_page - How many blocks fit in this page.
+ * i_blocks_per_folio - How many blocks fit in this folio.
  * @inode: The inode which contains the blocks.
@@ -1149,19 +1149,25 @@ static inline int page_mkwrite_check_truncate(struct page *page,
  *
- * If the block size is larger than the size of this page, return zero.
+ * If the block size is larger than the size of this folio, return zero.
  *
@@ -1149,19 +1149,25 @@ static inline int page_mkwrite_check_truncate(struct page *page,
  *
- * Context: The caller should hold a refcount on the page to prevent it
+ * Context: The caller should hold a refcount on the folio to prevent it
  * from being split.
@@ -1149,19 +1149,25 @@ static inline int page_mkwrite_check_truncate(struct page *page,
  * from being split.
- * Return: The number of filesystem blocks covered by this page.
+ * Return: The number of filesystem blocks covered by this folio.
  */
Weirdo formatting (same as i_blocks_per_page, but I'd still rather avoid
it).

Otherwise looks good:

Reviewed-by: Christoph Hellwig <hch@lst.de>
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help